@@ -26,7 +26,7 @@ use List::MoreUtils;
 use Data::Dumper;
 $Data::Dumper::Sortkeys =1;
 use NNexus::Concepts qw(links_from_concept);
-use Mojo::JSON;
+use Mojo::JSON qw(decode_json encode_json);
 
 sub serialize_concepts {
   my (%options) = @_;
@@ -105,8 +105,8 @@ sub serialize_concepts {
   } else {
     # stand-off case:
     if ($annotation eq 'json') {
-     my $json = Mojo::JSON->new;
-     return $json->encode($concepts); }
+     
+     return encode_json($concepts); }
     # when ('perl') { return Dumper($concepts); } #TODO: Why is this relevant? Testing?
     # TODO: Think of Markdown annotations
     # TODO: Stand-off HTML links
